@@ -1,7 +1,7 @@
 #' Find the operating system or architecture.
 #'
 #' Indicate whether we are on Windows or MacOSX.
-#' For MacOSX, we can also determine if we are on an x86-64 or Arm-based architecture.
+#' For MacOSX and Linux, we can also determine if we are on an x86-64 or Arm-based architecture.
 #'
 #' @return Logical scalar indicating whether we are on the specified OS and/or architecture.
 #'
@@ -10,6 +10,7 @@
 #' @examples
 #' isWindows()
 #' isMacOSX()
+#' isLinux()
 #' @export
 isWindows <- function() {
     .Platform$OS.type=="windows" 
@@ -24,5 +25,17 @@ isMacOSX <- function() {
 #' @export
 #' @rdname isWindows
 isMacOSXArm <- function() {
-    grepl("^arm", Sys.info()[["machine"]])
+    isMacOSX() && grepl("^arm", Sys.info()[["machine"]])
+}
+
+#' @export
+#' @rdname isWindows
+isLinux <- function() {
+    Sys.info()[["sysname"]] == "Linux"
+}
+
+#' @export
+#' @rdname isWindows
+isLinuxAarch64 <- function() {
+    isLinux() && Sys.info()[["machine"]] == "aarch64"
 }
